// cubeview.cpp : implementation of the CCubeView class
//
// This is a part of the Microsoft Foundation Classes C++ library.
// Copyright (C) 1992-1998 Microsoft Corporation
// All rights reserved.
//
// This source code is only intended as a supplement to the
// Microsoft Foundation Classes Reference and related
// electronic documentation provided with the library.
// See these sources for detailed information regarding the
// Microsoft Foundation Classes product.

#include "stdafx.h"
#include "cube.h"

#include "NowaGra.h"
#include "cubedoc.h"
#include "cubeview.h"

#include "gl\gl.h"
#include "gl\glu.h"
#include "gl\glaux.h"		
#include <string.h>

#include "Ustawienia.h"

#ifdef _DEBUG
#undef THIS_FILE
static char BASED_CODE THIS_FILE[] = __FILE__;
#endif

#define PLANSZA 1

#define DLUGOSC_BUFORA 64

#include "MainFrm.h"

unsigned char threeto8[8] =
{
	0, 0111>>1, 0222>>1, 0333>>1, 0444>>1, 0555>>1, 0666>>1, 0377
};

unsigned char twoto8[4] =
{
	0, 0x55, 0xaa, 0xff
};

unsigned char oneto8[2] =
{
	0, 255
};

static int defaultOverride[13] =
{
	0, 3, 24, 27, 64, 67, 88, 173, 181, 236, 247, 164, 91
};

static PALETTEENTRY defaultPalEntry[20] =
{
	{ 0,   0,   0,    0 },
	{ 0x80,0,   0,    0 },
	{ 0,   0x80,0,    0 },
	{ 0x80,0x80,0,    0 },
	{ 0,   0,   0x80, 0 },
	{ 0x80,0,   0x80, 0 },
	{ 0,   0x80,0x80, 0 },
	{ 0xC0,0xC0,0xC0, 0 },

	{ 192, 220, 192,  0 },
	{ 166, 202, 240,  0 },
	{ 255, 251, 240,  0 },
	{ 160, 160, 164,  0 },

	{ 0x80,0x80,0x80, 0 },
	{ 0xFF,0,   0,    0 },
	{ 0,   0xFF,0,    0 },
	{ 0xFF,0xFF,0,    0 },
	{ 0,   0,   0xFF, 0 },
	{ 0xFF,0,   0xFF, 0 },
	{ 0,   0xFF,0xFF, 0 },
	{ 0xFF,0xFF,0xFF, 0 }
};

/////////////////////////////////////////////////////////////////////////////
// CCubeView

IMPLEMENT_DYNCREATE(CCubeView, CView)


BEGIN_MESSAGE_MAP(CCubeView, CView)
	//{{AFX_MSG_MAP(CCubeView)
	ON_COMMAND(ID_FILE_PLAY, OnFilePlay)
	ON_UPDATE_COMMAND_UI(ID_FILE_PLAY, OnUpdateFilePlay)
	ON_WM_CREATE()
	ON_WM_DESTROY()
	ON_WM_SIZE()
	ON_WM_TIMER()
	ON_WM_ERASEBKGND()
	ON_WM_RBUTTONDOWN()
	ON_WM_LBUTTONDOWN()
	ON_WM_MOUSEMOVE()
	ON_WM_KEYDOWN()
	ON_BN_CLICKED(IDC_PAUZA, OnPauza)
	ON_BN_CLICKED(IDC_PIONKI_STANDARD, OnPionkiStandard)
	ON_BN_CLICKED(IDC_PIONKI_ARTDECO, OnPionkiArtdeco)
	ON_COMMAND(IDM_ZASADY, OnZasady)
	ON_COMMAND(IDM_AUTHORS, OnAuthors)
	ON_COMMAND(IDM_HELPTOPICS, OnHelptopics)
	ON_COMMAND(IDM_HOWPLAY, OnHowplay)
	ON_COMMAND(IDM_LICENSE, OnLicense)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CCubeView construction/destruction

CCubeView::CCubeView()
{
	m_pDC = NULL;
	m_pOldPalette = NULL;
}

CCubeView::~CCubeView()
{
}

/////////////////////////////////////////////////////////////////////////////
// CCubeView drawing

void CCubeView::OnDraw(CDC* pDC)
{
	CCubeDoc* pDoc = GetDocument();
	ASSERT_VALID(pDoc);

	
	DrawScene();
		
}


/////////////////////////////////////////////////////////////////////////////
// CCubeView diagnostics

#ifdef _DEBUG
void CCubeView::AssertValid() const
{
	CView::AssertValid();
}

void CCubeView::Dump(CDumpContext& dc) const
{
	CView::Dump(dc);
}

CCubeDoc* CCubeView::GetDocument() // non-debug version is inline
{
	return STATIC_DOWNCAST(CCubeDoc, m_pDocument);
}
#endif //_DEBUG

/////////////////////////////////////////////////////////////////////////////
// CCubeView message handlers

void CCubeView::OnFilePlay()
{
	TypGracza g1, g2;
	if(pierwsze_uruchomienie)
	{
		g1=Czlowiek;
		g2=Komputer;
	} else
	{
		g1=plan.KtoBialy.typ;
		g2=plan.KtoCzarny.typ;
	}
	
	NowaGra dialog(this,g1,g2);
	
	
	if(dialog.DoModal()==IDOK)
		{
			plan.KtoBialy.typ=dialog.GraczBialy;
			plan.KtoCzarny.typ=dialog.GraczCzarny;

			KonfNowaGre();
	}
}

bool CCubeView::czy_wszystkie_bicia_podswietlone(int valid_nr)
{
	bool semafor=true;
	bool temp[32];
	for(int i=0;i<32;i++)
		temp[i]=podswietl[i];
	for(i=0;i<32;i++)
	{
		if((plan.czyja_figura(plan.ustawienie[i].typ)==plan.przeciwny(CzyjaKolej))&&
			(plan.valid_moves[valid_nr].pola[i]==Pusty))
				temp[i]=!temp[i];
	}
	for(i=0;i<32;i++)
		if(temp[i])semafor=false;
	return semafor;
}

void CCubeView::Trafiony(int ktory)
{
	int i;

	if(plan.czyja_figura(plan.ustawienie[ktory].typ)==CzyjaKolej)
		{
			kursor=ktory;
			for(i=0;i<32;i++)podswietl[i]=0;
			DrawScene();
			return;
		}
	if(plan.czyja_figura(plan.ustawienie[kursor].typ)!=CzyjaKolej)return;
	if(plan.czyja_figura(plan.ustawienie[ktory].typ)==plan.przeciwny(CzyjaKolej))
		{
			podswietl[ktory]=!podswietl[ktory];  //sprawdz czy wogole mozna takie bicie
			DrawScene();
			return;
		}
	if(plan.ustawienie[ktory].typ==Pusty)
		{
			bool sem=false;
			for(i=0;i<plan.valid_moves_count;i++)
				if((plan.valid_moves[i].pola[kursor]==Pusty)&&
					(plan.czyja_figura(plan.valid_moves[i].pola[ktory])==CzyjaKolej)&&
					(czy_wszystkie_bicia_podswietlone(i)))
				{
					sem=true;
					break;
				}
			if(!sem)return;

			//ruch oraz czyszczenie podswietlen i kursora
			for(int j=0; j<32; j++)
			{
						plan.ustawienie[j].typ=plan.valid_moves[i].pola[j];
						podswietl[j]=false;
			}
			kursor=-1;
			

			CzyjaKolej=plan.przeciwny(CzyjaKolej);
			plan.get_possible_moves(CzyjaKolej);
			DrawScene();
			if(!plan.valid_moves_count)
					if(CzyjaKolej==Bialy)MessageBox("Zwyciestwo Czarnych");
					else {
							MessageBox("Zwyciestwo Biaych");
							return;
					}
						

			//uaktualnij text czyj ruch
			CMainFrame* pMainFrame=(CMainFrame*)GetParentFrame();
				CStatic *MyItem= (CStatic*)(pMainFrame->m_wndDlgBar.GetDlgItem(IDC_DLG_CZYJ_RUCH));
				if(CzyjaKolej==Bialy)MyItem->SetWindowText(CString((LPCTSTR)IDS_BIALE));
					else MyItem->SetWindowText(CString((LPCTSTR)IDS_CZARNE));
			//jesli gra z komputerem to ruch komputera, jesli nie to nic nie zrobi
			Ruch_Komputera();

			if(!plan.valid_moves_count)
					if(CzyjaKolej==Bialy)MessageBox(CString((LPCTSTR)IDS_WYGRANA_CZARNYCH));
						else MessageBox(CString((LPCTSTR)IDS_WYGRANA_BIALYCH));

		}

}

void CCubeView::OnLButtonDown(UINT, CPoint point)
{
  
  if(pierwsze_uruchomienie)
		{
			if(plan.czyja_figura(plan.ustawienie[xy2obiekt(point)].typ)==Bialy)
			{
				plan.KtoBialy.typ=Czlowiek;
				plan.KtoCzarny.typ=Komputer;
			}
			if(plan.czyja_figura(plan.ustawienie[xy2obiekt(point)].typ)==Czarny)
			{
				plan.KtoBialy.typ=Komputer;
				plan.KtoCzarny.typ=Czlowiek;
			}
			KonfNowaGre();
			OnLButtonDown(0, point);
			return;
		}
	else if(Czy_Pauza())return;

  int numer_obiektu=xy2obiekt(point);
  if(numer_obiektu<100)Trafiony(numer_obiektu);			
  
  return;
}

void CCubeView::OnRButtonDown( UINT nFlags, CPoint point )
{
	poprzednie_wsp=point;
}

void CCubeView::OnMouseMove(UINT nFlags, CPoint point)
{
	if(nFlags&MK_RBUTTON)
	{
		GLfloat tmp;
		tmp=wAngleX+(GLfloat)(point.y-poprzednie_wsp.y);
		if((tmp<0))
					if(tmp<-90)wAngleX=-90;
						else wAngleX=tmp;

		wAngleZ+=(GLfloat)(point.x-poprzednie_wsp.x);
		
		poprzednie_wsp=point;
		DrawScene();
	}
	return;
};


void CCubeView::OnKeyDown( UINT nChar, UINT nRepCnt, UINT nFlags )
{
	static int tmp;	


	if(nChar==32)	
		{
		/*CString t;
			t.Format("Ilosc przewidywanych ruchw: %i\nIlosc ruchw przewidzianych ostatnio: %i\nIlosc kombinacji na sekund: %i",
				plan.MAX_H,plan.stat_ile_kombinacji,1000*plan.stat_ile_kombinacji/plan.czas_ostatniego_ruchu_komp);
			MessageBox(t);*/

			CString t;
			t.Format("Deep of search: %i time of last searcg: %i",plan.MAX_H,plan.czas_ostatniego_ruchu_komp);
			MessageBox(t);

		};



	return;
}

void CCubeView::OnUpdateFilePlay(CCmdUI* pCmdUI)
{
	pCmdUI->SetCheck(m_play);
}

BOOL CCubeView::PreCreateWindow(CREATESTRUCT& cs)
{
	// An OpenGL window must be created with the following flags and must not
	// include CS_PARENTDC for the class style. Refer to SetPixelFormat
	// documentation in the "Comments" section for further information.
	cs.style |= WS_CLIPSIBLINGS | WS_CLIPCHILDREN;

	return CView::PreCreateWindow(cs);
}

int CCubeView::OnCreate(LPCREATESTRUCT lpCreateStruct)
{
	if (CView::OnCreate(lpCreateStruct) == -1)
		return -1;

	Init(); // initialize OpenGL


	return 0;
}

void CCubeView::OnDestroy()
{
	HGLRC   hrc;

	KillTimer(1);

	hrc = ::wglGetCurrentContext();

	::wglMakeCurrent(NULL,  NULL);

	if (hrc)
		::wglDeleteContext(hrc);

	if (m_pOldPalette)
		m_pDC->SelectPalette(m_pOldPalette, FALSE);

	if (m_pDC)
		delete m_pDC;

	CView::OnDestroy();
}

void CCubeView::OnSize(UINT nType, int cx, int cy)
{
	CView::OnSize(nType, cx, cy);

	if(cy > 0)
	{
		glViewport(0, 0, cx, cy);

		if((m_oldRect.right > cx) || (m_oldRect.bottom > cy))
			RedrawWindow();

		m_oldRect.right = cx;
		m_oldRect.bottom = cy;

		glMatrixMode(GL_PROJECTION);
		glLoadIdentity();
		fAspect=(GLfloat)cx/cy;
		gluPerspective(45.0f, fAspect, fNearPlane, fFarPlane);
		glMatrixMode(GL_MODELVIEW);
	}
}

void CCubeView::OnTimer(UINT nIDEvent)
{
	if(Pauza)return;	
	unsigned int czas;
	CStatic *MyItem;
	CString str;

	CMainFrame* pMainFrame=(CMainFrame*)GetParentFrame();
	if(CzyjaKolej==Bialy)
		{
			czas=++CzasBialy;
			MyItem= (CStatic*)(pMainFrame->m_wndDlgBar.GetDlgItem(IDC_DLG_CZAS_BIALYCH));
		}
		else 
		{
			czas=++CzasCzarny;
			MyItem= (CStatic*)(pMainFrame->m_wndDlgBar.GetDlgItem(IDC_DLG_CZAS_CZARNYCH));
		}

	str.Format("%02i:%02i:%02i", czas/36000%24,czas/600%60,czas/10%60);
	MyItem->SetWindowText(str);
	

	CView::OnTimer(nIDEvent);

	// Eat spurious WM_TIMER messages
	MSG msg;
	while(::PeekMessage(&msg, m_hWnd, WM_TIMER, WM_TIMER, PM_REMOVE));
}



/////////////////////////////////////////////////////////////////////////////
// GL helper functions

void CCubeView::Init()
{
	PIXELFORMATDESCRIPTOR pfd;
	int         n;
	HGLRC       hrc;


	m_pDC = new CClientDC(this);

	ASSERT(m_pDC != NULL);

	if (!bSetupPixelFormat())
		return;

	n = ::GetPixelFormat(m_pDC->GetSafeHdc());
	::DescribePixelFormat(m_pDC->GetSafeHdc(), n, sizeof(pfd), &pfd);

	CreateRGBPalette();

	hrc = wglCreateContext(m_pDC->GetSafeHdc());
	wglMakeCurrent(m_pDC->GetSafeHdc(), hrc);

	GetClientRect(&m_oldRect);
	//glClearDepth(2.0f);
	//glEnable(GL_DEPTH_TEST);

	//fAspect=(GLfloat)cx/cy;
			
	if (m_oldRect.bottom)
		fAspect = (GLfloat)m_oldRect.right/m_oldRect.bottom;
	else    // don't divide by zero, not that we should ever run into that...
		fAspect = 1;

	fNearPlane = 2.0f;
	fFarPlane = 7.0f;
	fMaxObjSize = 3.0f;
	m_fRadius = fNearPlane + fMaxObjSize / 2.0f;

	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();
	gluPerspective(45.0f, fAspect, fNearPlane, fFarPlane);
	glMatrixMode(GL_MODELVIEW);
	
	glShadeModel(GL_SMOOTH); //rodzaj cieniowania							
	glEnable(GL_DEPTH_TEST);
	
	GLfloat ambientLight[]={ 0.8f, 0.8f, 0.8f, 1.0};
	GLfloat specular[]={ 0.5f, 0.5f, 0.5f, 1.0};
	GLfloat diffuse[]={ 0.1f, 0.1f, 0.1f, 1.0};
	GLfloat lightPos[]={ 100.0f, 100.0f, 150.0f, 10.0};
	 
	glLightfv(GL_LIGHT0, GL_AMBIENT, ambientLight);
	glLightfv(GL_LIGHT0, GL_SPECULAR, specular);
	glLightfv(GL_LIGHT0, GL_DIFFUSE, specular);
	glLightfv(GL_LIGHT0, GL_POSITION, lightPos);
	
	glEnable(GL_COLOR_MATERIAL);	
	
	//odblyski materialow
	GLfloat specref[]={ 0.8f, 0.8f, 0.8f, 1.0f };
	glColorMaterial(GL_FRONT, GL_AMBIENT_AND_DIFFUSE);
	glMaterialfv(GL_FRONT, GL_SPECULAR, specref);
	glMateriali(GL_FRONT, GL_SHININESS, 128);

	glEnable(GL_LIGHTING);	
	glEnable(GL_LIGHT0);


	glClearColor(0.0f, 0.35f, 0.0f, 1.0f);
	glEnable(GL_TEXTURE_2D);  //test
	

	MakeScene();

	wAngleX=-60;
	wAngleY=0;
	wAngleZ=0;

	kursor=-1;
	Styl_Pionkow=0;

	Pauza=false;
	pierwsze_uruchomienie=true;
//	m_pDC->ResizeClient( int nWidth, int nHeight, BOOL bRedraw = FALSE );
}

BOOL CCubeView::bSetupPixelFormat()
{
	static PIXELFORMATDESCRIPTOR pfd =
	{
		sizeof(PIXELFORMATDESCRIPTOR),  // size of this pfd
		1,                              // version number
		PFD_DRAW_TO_WINDOW |            // support window
		  PFD_SUPPORT_OPENGL |          // support OpenGL
		  PFD_DOUBLEBUFFER,             // double buffered
		PFD_TYPE_RGBA,                  // RGBA type
		24,                             // 24-bit color depth
		0, 0, 0, 0, 0, 0,               // color bits ignored
		0,                              // no alpha buffer
		0,                              // shift bit ignored
		0,                              // no accumulation buffer
		0, 0, 0, 0,                     // accum bits ignored
		32,                             // 32-bit z-buffer
		0,                              // no stencil buffer
		0,                              // no auxiliary buffer
		PFD_MAIN_PLANE,                 // main layer
		0,                              // reserved
		0, 0, 0                         // layer masks ignored
	};
	int pixelformat;

	if ( (pixelformat = ChoosePixelFormat(m_pDC->GetSafeHdc(), &pfd)) == 0 )
	{
		MessageBox("ChoosePixelFormat failed");
		return FALSE;
	}

	if (SetPixelFormat(m_pDC->GetSafeHdc(), pixelformat, &pfd) == FALSE)
	{
		MessageBox("SetPixelFormat failed");
		return FALSE;
	}

	return TRUE;
}

unsigned char CCubeView::ComponentFromIndex(int i, UINT nbits, UINT shift)
{
	unsigned char val;

	val = (unsigned char) (i >> shift);
	switch (nbits)
	{

	case 1:
		val &= 0x1;
		return oneto8[val];
	case 2:
		val &= 0x3;
		return twoto8[val];
	case 3:
		val &= 0x7;
		return threeto8[val];

	default:
		return 0;
	}
}


void CCubeView::CreateRGBPalette()
{
	PIXELFORMATDESCRIPTOR pfd;
	LOGPALETTE *pPal;
	int n, i;

	n = ::GetPixelFormat(m_pDC->GetSafeHdc());
	::DescribePixelFormat(m_pDC->GetSafeHdc(), n, sizeof(pfd), &pfd);

	if (pfd.dwFlags & PFD_NEED_PALETTE)
	{
		n = 1 << pfd.cColorBits;
		pPal = (PLOGPALETTE) new char[sizeof(LOGPALETTE) + n * sizeof(PALETTEENTRY)];

		ASSERT(pPal != NULL);

		pPal->palVersion = 0x300;
		pPal->palNumEntries = n;
		for (i=0; i<n; i++)
		{
			pPal->palPalEntry[i].peRed =
					ComponentFromIndex(i, pfd.cRedBits, pfd.cRedShift);
			pPal->palPalEntry[i].peGreen =
					ComponentFromIndex(i, pfd.cGreenBits, pfd.cGreenShift);
			pPal->palPalEntry[i].peBlue =
					ComponentFromIndex(i, pfd.cBlueBits, pfd.cBlueShift);
			pPal->palPalEntry[i].peFlags = 0;
		}

		/* fix up the palette to include the default GDI palette */
		if ((pfd.cColorBits == 8)                           &&
			(pfd.cRedBits   == 3) && (pfd.cRedShift   == 0) &&
			(pfd.cGreenBits == 3) && (pfd.cGreenShift == 3) &&
			(pfd.cBlueBits  == 2) && (pfd.cBlueShift  == 6)
		   )
		{
			for (i = 1 ; i <= 12 ; i++)
				pPal->palPalEntry[defaultOverride[i]] = defaultPalEntry[i];
		}

		m_cPalette.CreatePalette(pPal);
		delete pPal;

		m_pOldPalette = m_pDC->SelectPalette(&m_cPalette, FALSE);
		m_pDC->RealizePalette();
	}
}

void pionek(XY pos, int styl, GLfloat red, GLfloat green, GLfloat blue)
{
    // PIONEK
	glPushMatrix();
		
	glTranslatef((GLfloat)-1+(pos.x-1)*0.25+0.125,(GLfloat)-1+(pos.y-1)*0.250+0.125,0);
	GLUquadricObj* q = gluNewQuadric();

	if(!styl)
	{
		glColor3d( 0.6*red, 0.6*green, 0.6*blue);
		gluCylinder(q, 0.10f, 0.10f, 0.05f , 24, 1);
		glTranslatef( 0.0f, 0.0f, 0.05f);
		gluDisk( q, 0.06f, 0.10f, 24, 1 );

	
		glTranslatef( 0.0f, 0.0f,-0.02f);
		//glColor4d( 0.5*red, 0.5*green, 0.5*blue, 1);
		gluCylinder(q, 0.06f, 0.06f, 0.02f, 24, 1);


		glColor4d( 0.55*red, 0.55*green, 0.55*blue, 1);
		gluDisk(q, 0.0f, 0.06f, 24, 1);
		glTranslatef( 0.0f, 0.0f, -0.03f);

		glColor3d( 0.6*red, 0.6*green, 0.6*blue);
		gluCylinder(q, 0.06f, 0.06f, -4, 24, 1);
	}
	  else//if(styl==1)
	{
		glColor3d( 0.6*red, 0.6*green, 0.6*blue);
		gluCylinder(q, 0.10f, 0.0f, 0.10f , 32, 1);
		glTranslatef( 0.0f, 0.0f, 0.15f);
		//glColor3d( 0.5*red, 0.5*green, 0.5*blue);
		gluSphere(q, 0.05f, 24, 24);
	}
	gluDeleteQuadric( q );
	glPopMatrix();
}
void damka(XY pos, int styl, GLfloat red, GLfloat green, GLfloat blue)
{
    // PIONEK
	glPushMatrix();
	//glColor3d( 0.9*red, 0.9*green, 0.9*blue);
	
	glTranslatef((GLfloat)-1+(pos.x-1)*0.25+0.125,(GLfloat)-1+(pos.y-1)*0.250+0.125,0);
	GLUquadricObj* q = gluNewQuadric();

	if(!styl)
	{
		glColor3d( 0.6*red, 0.6*green, 0.6*blue);
		gluCylinder(q, 0.10f, 0.10f, 0.1f, 24, 1);
		glTranslatef( 0.0f, 0.0f, 0.1f);
		gluDisk( q, 0.06f, 0.10f, 24, 1 );
		glTranslatef( 0.0f, 0.0f, -0.05f);

		
		glTranslatef( 0.0f, 0.0f,-0.02f);
		//glColor4d( 0.6*red, 0.6*green, 0.6*blue, 1);
		gluCylinder(q, 0.06f, 0.06f, 0.05f, 24, 1);   //z 0.02f na 0.05f zmienilem


		//glColor4d( 0.8*red, 0.8*green, 0.8*blue, 1);
		glTranslatef( 0.0f, 0.0f, 0.03f);
		glColor4d( 0.55*red, 0.55*green, 0.55*blue, 1);
		gluDisk(q, 0.0f, 0.06f, 24, 1);
		glTranslatef( 0.0f, 0.0f, -0.3f);
		glColor3d( 0.6*red, 0.6*green, 0.6*blue);
		gluCylinder(q, 0.06f, 0.06f, -4, 24, 1);
	}
	  else
	{
		glColor3d( 0.6*red, 0.6*green, 0.6*blue);
		gluCylinder(q, 0.10f, 0.0f, 0.10f , 32, 1);
    
		gluDisk( q, 0.0f, 0.07f, 4, 1 );
		glTranslatef( 0.0f, 0.0f, 0.10f);
		gluCylinder(q, 0.07f, 0.07f, 0.10f , 4, 1);
		glTranslatef( 0.0f, 0.0f, 0.10f);
		gluDisk( q, 0.0f, 0.07f, 4, 1 );

		glTranslatef( 0.0f, 0.0f, 0.04f);
		gluSphere(q, 0.05f, 132, 24);

	}
	gluDeleteQuadric( q );
	glPopMatrix();
}

void CCubeView::MakeScene(void)
{

//tworzenie list wyswietlania dla planszy
	glNewList(PLANSZA, GL_COMPILE);
	//szachownica      

    
	
//drewno wokol szachownicy
	glColor4d( 0.5, 0.25, 0.0, 1);
	

	
	glBegin(GL_QUADS);
			glVertex3f( -1.1, -1.1, 0);
			glVertex3f( 1.1, -1.1, 0);
			glVertex3f( 1.0, -1.0, 0);
			glVertex3f( -1.0, -1.0, 0);
	
			glVertex3f( 1.1, 1.1, 0);
			glVertex3f( -1.1, 1.1, 0);
			glVertex3f( -1.0, 1.0, 0);
			glVertex3f( 1.0, 1.0, 0);
	
			glVertex3f( -1.1, 1.1, 0);
			glVertex3f( -1.1, -1.1, 0);
			glVertex3f( -1.0, -1.0, 0);
			glVertex3f( -1.0, 1.0, 0);

			glVertex3f( 1.1, 1.1, 0);
			glVertex3f( 1.1, -1.1, 0);
			glVertex3f( 1.0, -1.0, 0);
			glVertex3f( 1.0, 1.0, 0);
	glEnd();

// drewno scianki
	glColor4d( 0.326, 0.166, 0.0, 1);
	glBegin(GL_QUADS);


			glVertex3f( -1.1, -1.1, 0);
			glVertex3f( 1.1, -1.1, 0);
			glVertex3f( 1.1, -1.1, -0.1);
			glVertex3f( -1.1, -1.1, -0.1);

			glVertex3f( -1.1, 1.1, 0);
			glVertex3f( 1.1, 1.1, 0);
			glVertex3f( 1.1, 1.1, -0.1);
			glVertex3f( -1.1, 1.1, -0.1);
			
			glVertex3f( -1.1, 1.1, 0);
			glVertex3f( -1.1, -1.1, 0);
			glVertex3f( -1.1, -1.1, -0.1);
			glVertex3f( -1.1, 1.1, -0.1);

			glVertex3f( 1.1, 1.1, 0);
			glVertex3f( 1.1, -1.1, 0);
			glVertex3f( 1.1, -1.1, -0.1);
			glVertex3f( 1.1, 1.1, -0.1);
	glEnd();
// drewno spod planszy
	glBegin(GL_QUADS);
			
			glVertex3f( -1.1, -1.1, -0.1);
			glVertex3f( 1.1, -1.1, -0.1);
			glVertex3f( 1.1, 1.1, -0.1);
			glVertex3f( -1.1, 1.1, -0.1);
	glEnd();

	glEndList();

}


void podswietl_pole(int x, int y, GLfloat r, GLfloat g, GLfloat b)
{
	glBegin(GL_QUADS);

	glColor4d( r, g , b, 1);
    glVertex3f(-1+x*0.25, -1+y*0.25, 0.001);
    glVertex3f(-1+x*0.25+0.25, -1+y*0.25, 0.001);
    glVertex3f(-1+x*0.25+0.25, -1+y*0.25+0.25, 0.001);
    glVertex3f(-1+x*0.25, -1+y*0.25+0.25, 0.001);

	glEnd();
}

void CCubeView::DrawScene(void)
{
	
	static BOOL     bBusy = FALSE;

	if(bBusy)
		return;
	bBusy = TRUE;


	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
	
	glPushMatrix();

		glTranslatef(0.0f, 0.0f, -m_fRadius);
		glRotatef(wAngleX, 1.0f, 0.0f, 0.0f);
		glRotatef(wAngleY, 0.0f, 1.0f, 0.0f);
		glRotatef(wAngleZ, 0.0f, 0.0f, 1.0f);

	glInitNames();
	glPushName(0);

    char tmp;
	for(int i=0; i<8; i++)
	for(int j=0;j<8; j++)
	    {
		  if((i+j%2+1)%2) 
		  {
			  tmp=plan.XYtoI(i+1,j+1);
			  glLoadName(tmp);	
		  } else glLoadName(100);
		  
		  if((i+j%2)%2) glColor4d( 1.0, 1.0, 1.0, 1 ); 
			else glColor4d( 0.1, 0.1 , 0.1, 1);
	
//			glCallList(Textura_Drewno);					  
		  glBegin(GL_QUADS);	
	      glVertex3f(-1+i*0.25, -1+j*0.25, 0);
	      glVertex3f(-1+i*0.25+0.25, -1+j*0.25, 0);
	      glVertex3f(-1+i*0.25+0.25, -1+j*0.25+0.25, 0);
	      glVertex3f(-1+i*0.25, -1+j*0.25+0.25, 0);
		  glEnd();
	    }
    glLoadName(100);

   	temp=temp+1;
	for( i=0;i<32;i++)
		{ 
			
			if (plan.ustawienie[i].typ==Bialy)
				pionek( plan.ItoXY(i),Styl_Pionkow, 1.0f, 1.0f,1.0f);					
			if (plan.ustawienie[i].typ==BialaDamka)
				damka( plan.ItoXY(i),Styl_Pionkow, 1.0f,1.0f,1.0f);						
			if (plan.ustawienie[i].typ==Czarny)
				pionek( plan.ItoXY(i),Styl_Pionkow, 0.6f, 0.6f, 0.6f);				
			if (plan.ustawienie[i].typ==CzarnaDamka)
				damka( plan.ItoXY(i),Styl_Pionkow, 0.6f,0.6f,0.6f);				
			
		}
	glCallList(PLANSZA);

//kursor i podswietlenie
	XY kurs;
	for(i=0;i<32;i++)
		if(podswietl[i]==true)
				{
					kurs=plan.ItoXY(i);
					podswietl_pole(kurs.x-1, kurs.y-1, 0.2f, 0.5f, 0.2f);
				};

	if (kursor>=0)
		{
			kurs=plan.ItoXY(kursor);
			podswietl_pole(kurs.x-1, kurs.y-1, 0.2f, 0.4f, 0.2f);
		}
	

    glPopMatrix();
	glFinish();
	SwapBuffers(wglGetCurrentDC());

	bBusy = FALSE;
}

BOOL CCubeView::OnEraseBkgnd(CDC* pDC)
{
	return TRUE;
}

int CCubeView::xy2obiekt(CPoint point)
{
		int numer_obiektu;
	
		GLuint selectBuff[DLUGOSC_BUFORA];		
		GLint hits, viewport[4];

		glSelectBuffer(DLUGOSC_BUFORA, selectBuff);

		glGetIntegerv(GL_VIEWPORT, viewport);

		glMatrixMode(GL_PROJECTION);
		glPushMatrix();

		glRenderMode(GL_SELECT);

		glLoadIdentity();

		gluPickMatrix(point.x, viewport[3]-point.y, 2,2, viewport);

		gluPerspective(45.0f, fAspect, fNearPlane, fFarPlane);

		DrawScene();

		hits=glRenderMode(GL_RENDER);

		if(hits>0)
		{
			numer_obiektu=selectBuff[3];
		} else numer_obiektu=100;

		glMatrixMode(GL_PROJECTION);
		glPopMatrix();

		glMatrixMode(GL_MODELVIEW);
		return numer_obiektu;
}

void CCubeView::Ruch_Komputera()
{
	if(((CzyjaKolej==Bialy)&&(plan.KtoBialy.typ==Komputer))||
				((CzyjaKolej==Czarny)&&(plan.KtoCzarny.typ==Komputer)))
			{
				CWaitCursor wait;
				plan.Ruch_Komputera(CzyjaKolej);
				CzyjaKolej=plan.przeciwny(CzyjaKolej);
				DrawScene();
				plan.get_possible_moves(CzyjaKolej);

				CMainFrame* pMainFrame=(CMainFrame*)GetParentFrame();
				CStatic *MyItem= (CStatic*)(pMainFrame->m_wndDlgBar.GetDlgItem(IDC_DLG_CZYJ_RUCH));
				if(CzyjaKolej==Bialy)MyItem->SetWindowText(CString((LPCTSTR)IDS_BIALE));
					else MyItem->SetWindowText(CString((LPCTSTR)IDS_CZARNE));
			}
}


bool CCubeView::Czy_Pauza()
{
	if(Pauza)
	{
			MessageBox("Turn off the pause");
			return true;
	} else return false;
}

void CCubeView::OnPauza() 
{
	// TODO: Add your control notification handler code here
	Pauza=!Pauza;
}

void CCubeView::OnPionkiStandard() 
{
	// TODO: Add your control notification handler code here
	Styl_Pionkow=0;
	DrawScene();
}

void CCubeView::OnPionkiArtdeco() 
{
	// TODO: Add your control notification handler code here
	Styl_Pionkow=1;
	DrawScene();
}


void CCubeView::OnZasady() 
{
	// TODO: Add your command handler code here

	WinHelp(2);
}

void CCubeView::KonfNowaGre()
{
			pierwsze_uruchomienie=false;

			plan.KtoBialy.Nazwa=CString("00:00:00");
			plan.KtoCzarny.Nazwa=CString("00:00:00");

			plan.zeruj_plansze();
			
			CzyjaKolej=Bialy;

			//do zmiany elementow na DialogBar
			CMainFrame* pMainFrame=(CMainFrame*)GetParentFrame();			
			CButton *MyBut=(CButton*)(pMainFrame->m_wndDlgBar.GetDlgItem(IDC_PAUZA));
			MyBut->SetCheck(false);
			

			Pauza=false;

			DrawScene();
			plan.get_possible_moves(CzyjaKolej);
		// Poczatek gry

			
			CStatic *MyItem;

			KillTimer(1);
			if((plan.KtoBialy.typ!=Komputer)&&(plan.KtoCzarny.typ!=Komputer))
			{
				SetTimer(1, 100, 0);
				MyItem= (CStatic*)(pMainFrame->m_wndDlgBar.GetDlgItem(IDC_DLG_CZAS_BIALYCH));
				MyItem->SetWindowText("00:00:00");
				MyItem->EnableWindow(true);
				MyItem->SetWindowText(plan.KtoBialy.Nazwa);
	
				MyItem= (CStatic*)(pMainFrame->m_wndDlgBar.GetDlgItem(IDC_DLG_CZAS_CZARNYCH));
				MyItem->SetWindowText("00:00:00");
				MyItem->EnableWindow(true);
				MyItem->SetWindowText(plan.KtoCzarny.Nazwa);
			}
				else
				{
					MyItem= (CStatic*)(pMainFrame->m_wndDlgBar.GetDlgItem(IDC_DLG_CZAS_BIALYCH));
					MyItem->SetWindowText("00:00:00");
					MyItem->EnableWindow(false);
	
					MyItem= (CStatic*)(pMainFrame->m_wndDlgBar.GetDlgItem(IDC_DLG_CZAS_CZARNYCH));
					MyItem->SetWindowText("00:00:00");
					MyItem->EnableWindow(false);
				}
			
			MyItem= (CStatic*)(pMainFrame->m_wndDlgBar.GetDlgItem(IDC_DLG_CZYJ_RUCH));
			MyItem->SetWindowText(CString((LPCTSTR)IDS_BIALE));

			if(plan.KtoBialy.typ==Czlowiek)wAngleZ=0;
				else wAngleZ=-180;

			DrawScene();
		// jesli zaczyna komputer to niech sie rusza
			Ruch_Komputera();
}

void CCubeView::OnAuthors() 
{
	// TODO: Add your command handler code here
	WinHelp(5);
}

void CCubeView::OnHelptopics() 
{
	// TODO: Add your command handler code here
	WinHelp(1);
}

void CCubeView::OnHowplay() 
{
	// TODO: Add your command handler code here
	WinHelp(3);
}

void CCubeView::OnLicense() 
{
	// TODO: Add your command handler code here
	WinHelp(4);
}
